@@ -2,12 +2,14 @@ import os
 import tempfile
 
 import pytest
+
 from flaskr import create_app
-from flaskr.db import get_db, init_db
+from flaskr.db import get_db
+from flaskr.db import init_db
 
 # read in SQL for populating test data
-with open(os.path.join(os.path.dirname(__file__), 'data.sql'), 'rb') as f:
-    _data_sql = f.read().decode('utf8')
+with open(os.path.join(os.path.dirname(__file__), "data.sql"), "rb") as f:
+    _data_sql = f.read().decode("utf8")
 
 
 @pytest.fixture
@@ -16,10 +18,7 @@ def app():
     # create a temporary file to isolate the database for each test
     db_fd, db_path = tempfile.mkstemp()
     # create the app with common test config
-    app = create_app({
-        'TESTING': True,
-        'DATABASE': db_path,
-    })
+    app = create_app({"TESTING": True, "DATABASE": db_path})
 
     # create the database and load test data
     with app.app_context():
@@ -49,14 +48,13 @@ class AuthActions(object):
     def __init__(self, client):
         self._client = client
 
-    def login(self, username='test', password='test'):
+    def login(self, username="test", password="test"):
         return self._client.post(
-            '/auth/login',
-            data={'username': username, 'password': password}
+            "/auth/login", data={"username": username, "password": password}
         )
 
     def logout(self):
-        return self._client.get('/auth/logout')
+        return self._client.get("/auth/logout")
 
 
 @pytest.fixture
