@@ -5,37 +5,36 @@
 
     Tests the application context.
 
-    :copyright: © 2010 by the Pallets team.
-    :license: BSD, see LICENSE for more details.
+    :copyright: 2010 Pallets
+    :license: BSD-3-Clause
 """
-
 import pytest
 
 import flask
 
 
 def test_basic_url_generation(app):
-    app.config['SERVER_NAME'] = 'localhost'
-    app.config['PREFERRED_URL_SCHEME'] = 'https'
+    app.config["SERVER_NAME"] = "localhost"
+    app.config["PREFERRED_URL_SCHEME"] = "https"
 
-    @app.route('/')
+    @app.route("/")
     def index():
         pass
 
     with app.app_context():
-        rv = flask.url_for('index')
-        assert rv == 'https://localhost/'
+        rv = flask.url_for("index")
+        assert rv == "https://localhost/"
 
 
 def test_url_generation_requires_server_name(app):
     with app.app_context():
         with pytest.raises(RuntimeError):
-            flask.url_for('index')
+            flask.url_for("index")
 
 
 def test_url_generation_without_context_fails():
     with pytest.raises(RuntimeError):
-        flask.url_for('index')
+        flask.url_for("index")
 
 
 def test_request_context_means_app_context(app):
@@ -71,7 +70,7 @@ def test_app_tearing_down_with_previous_exception(app):
         cleanup_stuff.append(exception)
 
     try:
-        raise Exception('dummy')
+        raise Exception("dummy")
     except Exception:
         pass
 
@@ -90,7 +89,7 @@ def test_app_tearing_down_with_handled_exception_by_except_block(app):
 
     with app.app_context():
         try:
-            raise Exception('dummy')
+            raise Exception("dummy")
         except Exception:
             pass
 
@@ -98,77 +97,79 @@ def test_app_tearing_down_with_handled_exception_by_except_block(app):
 
 
 def test_app_tearing_down_with_handled_exception_by_app_handler(app, client):
-    app.config['PROPAGATE_EXCEPTIONS'] = True
+    app.config["PROPAGATE_EXCEPTIONS"] = True
     cleanup_stuff = []
 
     @app.teardown_appcontext
     def cleanup(exception):
         cleanup_stuff.append(exception)
 
-    @app.route('/')
+    @app.route("/")
     def index():
-        raise Exception('dummy')
+        raise Exception("dummy")
 
     @app.errorhandler(Exception)
     def handler(f):
         return flask.jsonify(str(f))
 
     with app.app_context():
-        client.get('/')
+        client.get("/")
 
     assert cleanup_stuff == [None]
 
 
 def test_app_tearing_down_with_unhandled_exception(app, client):
-    app.config['PROPAGATE_EXCEPTIONS'] = True
+    app.config["PROPAGATE_EXCEPTIONS"] = True
     cleanup_stuff = []
 
     @app.teardown_appcontext
     def cleanup(exception):
         cleanup_stuff.append(exception)
 
-    @app.route('/')
+    @app.route("/")
     def index():
-        raise Exception('dummy')
+        raise Exception("dummy")
 
     with pytest.raises(Exception):
         with app.app_context():
-            client.get('/')
+            client.get("/")
 
     assert len(cleanup_stuff) == 1
     assert isinstance(cleanup_stuff[0], Exception)
-    assert str(cleanup_stuff[0]) == 'dummy'
+    assert str(cleanup_stuff[0]) == "dummy"
 
 
 def test_app_ctx_globals_methods(app, app_ctx):
     # get
-    assert flask.g.get('foo') is None
-    assert flask.g.get('foo', 'bar') == 'bar'
+    assert flask.g.get("foo") is None
+    assert flask.g.get("foo", "bar") == "bar"
     # __contains__
-    assert 'foo' not in flask.g
-    flask.g.foo = 'bar'
-    assert 'foo' in flask.g
+    assert "foo" not in flask.g
+    flask.g.foo = "bar"
+    assert "foo" in flask.g
     # setdefault
-    flask.g.setdefault('bar', 'the cake is a lie')
-    flask.g.setdefault('bar', 'hello world')
-    assert flask.g.bar == 'the cake is a lie'
+    flask.g.setdefault("bar", "the cake is a lie")
+    flask.g.setdefault("bar", "hello world")
+    assert flask.g.bar == "the cake is a lie"
     # pop
-    assert flask.g.pop('bar') == 'the cake is a lie'
+    assert flask.g.pop("bar") == "the cake is a lie"
     with pytest.raises(KeyError):
-        flask.g.pop('bar')
-    assert flask.g.pop('bar', 'more cake') == 'more cake'
+        flask.g.pop("bar")
+    assert flask.g.pop("bar", "more cake") == "more cake"
     # __iter__
-    assert list(flask.g) == ['foo']
+    assert list(flask.g) == ["foo"]
+    # __repr__
+    assert repr(flask.g) == "<flask.g of 'flask_test'>"
 
 
 def test_custom_app_ctx_globals_class(app):
     class CustomRequestGlobals(object):
         def __init__(self):
-            self.spam = 'eggs'
+            self.spam = "eggs"
 
     app.app_ctx_globals_class = CustomRequestGlobals
     with app.app_context():
-        assert flask.render_template_string('{{ g.spam }}') == 'eggs'
+        assert flask.render_template_string("{{ g.spam }}") == "eggs"
 
 
 def test_context_refcounts(app, client):
@@ -176,25 +177,25 @@ def test_context_refcounts(app, client):
 
     @app.teardown_request
     def teardown_req(error=None):
-        called.append('request')
+        called.append("request")
 
     @app.teardown_appcontext
     def teardown_app(error=None):
-        called.append('app')
+        called.append("app")
 
-    @app.route('/')
+    @app.route("/")
     def index():
         with flask._app_ctx_stack.top:
             with flask._request_ctx_stack.top:
                 pass
         env = flask._request_ctx_stack.top.request.environ
-        assert env['werkzeug.request'] is not None
-        return u''
+        assert env["werkzeug.request"] is not None
+        return u""
 
-    res = client.get('/')
+    res = client.get("/")
     assert res.status_code == 200
-    assert res.data == b''
-    assert called == ['request', 'app']
+    assert res.data == b""
+    assert called == ["request", "app"]
 
 
 def test_clean_pop(app):
@@ -207,7 +208,7 @@ def test_clean_pop(app):
 
     @app.teardown_appcontext
     def teardown_app(error=None):
-        called.append('TEARDOWN')
+        called.append("TEARDOWN")
 
     try:
         with app.test_request_context():
@@ -215,5 +216,5 @@ def test_clean_pop(app):
     except ZeroDivisionError:
         pass
 
-    assert called == ['flask_test', 'TEARDOWN']
+    assert called == ["flask_test", "TEARDOWN"]
     assert not flask.current_app
