@@ -6,12 +6,10 @@
     Test that certain behavior of flask can be customized by
     subclasses.
 
-    :copyright: © 2010 by the Pallets team.
-    :license: BSD, see LICENSE for more details.
+    :copyright: 2010 Pallets
+    :license: BSD-3-Clause
 """
-
 import flask
-
 from flask._compat import StringIO
 
 
@@ -23,11 +21,11 @@ def test_suppressed_exception_logging():
     out = StringIO()
     app = SuppressedFlask(__name__)
 
-    @app.route('/')
+    @app.route("/")
     def index():
-        raise Exception('test')
+        raise Exception("test")
 
-    rv = app.test_client().get('/', errors_stream=out)
+    rv = app.test_client().get("/", errors_stream=out)
     assert rv.status_code == 500
-    assert b'Internal Server Error' in rv.data
+    assert b"Internal Server Error" in rv.data
     assert not out.getvalue()
